Signal processing
=================

.. https://docs.scipy.org/doc/scipy/reference/signal.html

Convolution
-----------

.. autosummary::
   :toctree: generated/
   :nosignatures:

    cupyx.scipy.signal.choose_conv_method
